@@ -5,7 +5,7 @@ use warnings;
 use Carp;
 use Cwd 'realpath';
 
-our $VERSION   = '1.3091';
+our $VERSION   = '1.3094';
 our $AUTHORITY = 'SUKRIA';
 
 use Dancer::App;
@@ -179,7 +179,8 @@ sub pass            { Dancer::SharedData->response->pass(1);
 sub patch            { Dancer::App->current->registry->universal_add('patch', @_) }
 sub path            { Dancer::FileUtils::path(@_) }
 sub post            { Dancer::App->current->registry->universal_add('post', @_) }
-sub prefix          { Dancer::App->current->set_prefix(@_) }
+sub prefix          { @_ == 0 ? Dancer::App->current->get_prefix :
+                          Dancer::App->current->set_prefix(@_) }
 sub put             { Dancer::App->current->registry->universal_add('put',     @_) }
 sub redirect        { goto &_redirect }
 sub render_with_layout { Dancer::Template::Abstract->_render_with_layout(@_) }
@@ -531,7 +532,7 @@ your app.  You can control the exporting through the normal
 L<Exporter> mechanism.  For example:
 
     # Just export the route controllers
-    use Dancer qw(before after get post put patch);
+    use Dancer qw(get post put patch del);
 
     # Export everything but pass to avoid clashing with Test::More
     use Test::More;
@@ -582,26 +583,23 @@ By default, the L<warnings> pragma will also be exported, meaning your
 app/script will be running under C<use warnings>.  If you do not want this, set
 the L<import_warnings|Dancer::Config/import_warnings> setting to a false value.
 
+=head2 !keyword
+
+If you want to simply prevent Dancer from exporting specific keywords (perhaps
+you plan to implement them yourself in a different way, or you don't plan to use
+them and they clash with another module you're loading), you can simply exclude
+them:
+
+    use Dancer qw(!session);
+
+The above would import all keywords as normal, with the exception of C<session>.
+
 
 =head1 FUNCTIONS
 
 =head2 after
 
-Add a hook at the B<after> position:
-
-    after sub {
-        my $response = shift;
-        # do something with response, e.g.:
-        $response->header('X-Beer' => 'Yes please');
-    };
-
-The anonymous function which is given to C<after> will be executed after
-having executed a route, but before the response is returned (so you can modify
-the response here, if you need to)..
-
-You can define multiple after filters, using the C<after> helper as
-many times as you wish; each filter will be executed, in the order you added
-them.
+Deprecated - see the C<after> L<hook|Dancer/hook>.
 
 =head2 any
 
@@ -619,48 +617,11 @@ Or even, a route handler that would match any HTTP methods:
 
 =head2 before
 
-Defines a before filter:
-
-    before sub {
-        # do something with request, vars or params
-    };
-
-The anonymous function given to C<before> will be executed before executing a
-route handler to handle the request.
-
-If the function modifies the request's C<path_info> or C<method>, a new
-search for a matching route is performed and the filter is re-executed.
-Considering that this can lead to an infinite loop, this mechanism
-is stopped after 10 times with an exception.
-
-The before filter can set a response with a redirection code (either
-301 or 302): in this case the matched route (if any) will be ignored and the
-redirection will be performed immediately.
-
-You can define multiple before filters, using the C<before> helper as
-many times as you wish; each filter will be executed in the order you added
-them.
+Deprecated - see the C<before> L<hook|Dancer/hook>.
 
 =head2 before_template
 
-Defines a before_template filter:
-
-    before_template sub {
-        my $tokens = shift;
-        # do something with request, vars or params
-        
-        # for example, adding a token to the template
-        $tokens->{token_name} = "some value";
-    };
-
-The anonymous function which is given to C<before_template> will be executed
-before sending data and tokens to the template. Receives a HashRef of the
-tokens that will be inserted into the template.
-
-This filter works as the C<before> and C<after> filter.
-
-Now the preferred way for this is to use C<hook>s (namely, the
-C<before_template> one). Check C<hook> documentation below.
+Deprecated - see the C<before_template> L<hook|Dancer/hook>.
 
 =head2 cookies
 
@@ -773,13 +734,12 @@ application.
 
 It effectively lets you chain routes together in a clean manner.
 
-    get qr{ /demo/articles/(.+) }x => sub {
-        my ($article_id) = splat;
+    get '/demo/articles/:article_id' => sub {
 
         # you'll have to implement this next sub yourself :)
         change_the_main_database_to_demo();
 
-        forward '/articles/$article_id';
+        forward "/articles/" . params->{article_id};
     };
 
 In the above example, the users that reach I</demo/articles/30> will actually
@@ -790,19 +750,19 @@ database by merely going to I</demo/...>.
 
 You'll notice that in the example we didn't indicate whether it was B<GET> or
 B<POST>. That is because C<forward> chains the same type of route the user
-reached. If it was a B<GET>, it will remain a B<GET>.
+reached. If it was a B<GET>, it will remain a B<GET> (but if you do need to
+change the method, you can do so; read on below for details.)
 
-Broader functionality might be added in the future.
 
 B<WARNING> : Issuing a forward immediately exits the current route,
 and perform the forward. Thus, any code after a forward is ignored, until the
 end of the route. e.g.
 
-    get '/some/path => sub {
+    get '/foo/:article_id' => sub {
         if ($condition) {
-            forward '/articles/$article_id';
+            forward "/articles/" . params->{article_id};
             # The following code is never executed
-            do_stuf();
+            do_stuff();
         }
 
         more_stuff();
@@ -965,17 +925,17 @@ This hook receives as argument a L<Dancer::Error> object.
 
 =item before
 
-This is an alias to C<before>.
+This hook receives one argument, a reference to the subroutine that
+implements the route that is being intercepted by this hook.
 
-This hook receives no arguments.
-
-  before sub {
+  hook before => sub {
+    my $route_handler = shift;
     ...
   };
 
-is equivalent to
+it is equivalent to the deprecated
 
-  hook before => sub {
+  before sub {
     ...
   };
 
